@@ -83,7 +83,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct InspectorPage(ObjectSubclass<imp::InspectorPage>)
-        @extends gtk::Widget;
+        @extends gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl InspectorPage {
