@@ -104,7 +104,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct AlbumCover(ObjectSubclass<imp::AlbumCover>)
-        @extends gtk::Widget;
+        @extends gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl AlbumCover {
