@@ -66,7 +66,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct InformationRow(ObjectSubclass<imp::InformationRow>)
-        @extends gtk::Widget, adw::PreferencesRow;
+        @extends gtk::Widget, gtk::ListBoxRow, adw::PreferencesRow, adw::ActionRow,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget, gtk::Actionable;
 }
 
 impl InformationRow {
