@@ -78,7 +78,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PlaybackButton(ObjectSubclass<imp::PlaybackButton>)
-        @extends gtk::Widget, gtk::Button;
+        @extends gtk::Widget, gtk::Button,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget, gtk::Actionable;
 }
 
 impl PlaybackButton {
