@@ -108,7 +108,8 @@ mod imp {
 
 glib::wrapper! {
      pub struct ProgressIcon(ObjectSubclass<imp::ProgressIcon>)
-        @extends gtk::Widget;
+        @extends gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl ProgressIcon {
