@@ -97,7 +97,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct Waveform(ObjectSubclass<imp::Waveform>)
-        @extends gtk::Widget;
+        @extends gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl Waveform {
